### Расширенные параметры

Этот раздел предназначен для опытных пользователей данного программного обеспечения. Здесь вы можете найти:

1. [**Расширенные параметры**](./advanced.md)
<br>
В этом разделе вы можете указать исходный/целевой языки, переключить службы перевода и многое другое.

2. [**Код языка**](./Language-Codes.md)
<br>
Если вы не уверены, какие коды использовать для перевода исходного/целевого языков, вы можете найти их здесь.

3. [**Документация служб перевода**](./Documentation-of-Translation-Services.md)
<br>
Если вам нужно ознакомиться с документацией, предоставляемой используемыми службами перевода, обратитесь к этой странице.

<div align="right"> 
<h6><small>Часть содержимого этой страницы была переведена GPT и может содержать ошибки.</small></h6>